@@ -482,7 +482,11 @@ class ProxyURI(object):
                     cipher.plugins.append(plugin)
         match = cls.compile_rule(url.query) if url.query else None
         if loc:
-            host_name, _, port = loc.rpartition(':')
+            ipv6 = re.fullmatch('\[([0-9a-fA-F:]*)\](?::(\d+)?)?', loc)
+            if ipv6:
+                host_name, port = loc.groups()
+            else:
+                host_name, _, port = loc.partition(':')
             port = int(port) if port else (22 if 'ssh' in rawprotos else 8080)
         else:
             host_name = port = None
